@@ -514,11 +514,13 @@ void MainWindow::runscript(QString command)
         sleep(2);
         system("killall hildon-status-menu");
         sleep(2);
-        system("killall osso-abook-home-applet");
-        sleep(2);
         system("killall systemui");
+        sleep(2);
+        system("killall rtcom-messaging-ui");
         progress.setValue(99);
         sleep(2);
+        system("killall rtcom-call-ui");
+        sleep(2);
         system("run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
         sleep(4);
         system("killall hildon-desktop");
@@ -755,7 +757,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: D-Iivil - Licence: Freeware & open source");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-36<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-37<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
